@@ -12,6 +12,7 @@
 //               paintEvent wird aufgerufen, falls fenster berdeckt wird,
 //               oder auch einfach bewegt wird
 
+#include <config.h>
 
 #include "molek.moc"
 #include <kiconloader.h>
@@ -26,7 +27,7 @@
 extern int level;
 
 Molek::Molek( QWidget *parent, const char *name ) : QWidget( parent, name ),
-                                                    data( locate( "appdata", "pics/molek.png" ) )
+                                                    data(locate("appdata", "pics/molek.png"))
 {
     setBackgroundColor (QColor (0, 0, 0));
     setMinimumSize(240, 200);
@@ -66,7 +67,7 @@ void Molek::load (const KSimpleConfig& config)
 	if (value.isNull())
            value = "";
 
-	strcpy(current.conn, value.ascii());
+	strlcpy(current.conn, value.ascii(), sizeof(current.conn));
 	kdWarning( atoms.find(current) != atoms.end() )
 	  << "OOOPS, duplicate atom definition in " << key << endl;
 	atoms.append(current);
@@ -75,12 +76,12 @@ void Molek::load (const KSimpleConfig& config)
 
     QString line;
 
-    for (int j = 0; j < 15; j++) {
+    for (int j = 0; j < MOLEK_SIZE; j++) {
 
 	key.sprintf("mole_%d", j);
 	line = config.readEntry(key);
 
-	for (int i = 0; i < 15; i++)
+	for (int i = 0; i < MOLEK_SIZE; i++)
 	    molek[i][j] = atom2int(line.at(i).latin1());
     }
 
@@ -92,8 +93,8 @@ void Molek::load (const KSimpleConfig& config)
     height = 0;
     width = 0;
 
-    for (int i = 0; i < 15; i++)
-		for (int j = 0; j < 15; j++) {
+    for (int i = 0; i < MOLEK_SIZE; i++)
+		for (int j = 0; j < MOLEK_SIZE; j++) {
 			if (molek [i][j] == 0)
 				continue;
 			if (i > width) width = i;
@@ -114,8 +115,8 @@ void Molek::paintEvent( QPaintEvent * )
     paint.drawText (7, height() - 36, mname);
     paint.drawText (7, height() - 18, st);
     // spielfeld gleich zeichnen
-    for (int i = 0; i < 15; i++)
-		for (int j = 0; j < 15; j++) {
+    for (int i = 0; i < MOLEK_SIZE; i++)
+		for (int j = 0; j < MOLEK_SIZE; j++) {
 			int x = 10 + i * 15;
 			int y = 10 + j * 15;
 
