@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "pixServer.h"
@@ -100,7 +100,7 @@ void PixServer::initPixmaps()
     pm.convertFromImage(qi,QPixmap::AvoidDither);
     for (int x = 0 ; x < 18; x++){
 		compuSnakePix[x].resize(BRICKSIZE, BRICKSIZE);
-		bitBlt(&compuSnakePix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, TRUE);
+		bitBlt(&compuSnakePix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, true);
 		compuSnakePix[x].setMask(compuSnakePix[x].createHeuristicMask());
     }
 
@@ -110,7 +110,7 @@ void PixServer::initPixmaps()
     pm.convertFromImage(qi,QPixmap::AvoidDither);
     for (int x = 0 ; x < 18; x++){
 		samyPix[x].resize(BRICKSIZE, BRICKSIZE);
-		bitBlt(&samyPix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, TRUE);
+		bitBlt(&samyPix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, true);
 		samyPix[x].setMask(samyPix[x].createHeuristicMask());
     }
 
@@ -120,7 +120,7 @@ void PixServer::initPixmaps()
     pm.convertFromImage(qi,QPixmap::AvoidDither);
     for (int x = 0 ; x < 4; x++){
 	ballPix[x].resize(BRICKSIZE, BRICKSIZE);
-	bitBlt(&ballPix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, TRUE);
+	bitBlt(&ballPix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, true);
 	ballPix[x].setMask(ballPix[x].createHeuristicMask());
     }
 
@@ -130,7 +130,7 @@ void PixServer::initPixmaps()
     pm.convertFromImage(qi,QPixmap::AvoidDither);
     for (int x = 0 ; x < 2; x++){
 	applePix[x].resize(BRICKSIZE, BRICKSIZE);
-	bitBlt(&applePix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, TRUE);
+	bitBlt(&applePix[x] ,0,0, &pm,x*BRICKSIZE, 0, BRICKSIZE, BRICKSIZE, Qt::CopyROP, true);
 	applePix[x].setMask(applePix[x].createHeuristicMask());
     }
 }
@@ -138,11 +138,11 @@ void PixServer::initPixmaps()
 void PixServer::initbackPixmaps()
 {
 	QString path;
-	plainColor = FALSE;
+	plainColor = false;
 
 	if(Settings::bgcolor_enabled()){
 	    backgroundColor = Settings::bgcolor();
-	    plainColor = TRUE;
+	    plainColor = true;
 	} else if(Settings::bgimage_enabled()) {
 		// A bit of a hack.
 		QStringList backgroundPixmaps =
@@ -170,7 +170,7 @@ void PixServer::initbackPixmaps()
 	else  {
 	    kdDebug() << "error loading background image :" << path << endl;
 	    backgroundColor = (QColor("black"));
-	    plainColor = TRUE;
+	    plainColor = true;
 	}
     }
     if ( plainColor)
