@@ -3,8 +3,9 @@
 
 #include "base/main.h"
 
+#include <kdemacros.h>
 
-class MainWindow : public BaseMainWindow
+class KDE_EXPORT MainWindow : public BaseMainWindow
 {
     Q_OBJECT
 public:
